How to … — csdmpy 0.1.1 documentation

# How to …

The csdmpy module is not just designed for deserializing and serializing the .csdf or .csdfe files. It can also be used to create new datasets, a feature that is most useful when converting dataset to csdm compliant format.

- How to create a new dataset
- How to add instances of Dimension class
  - LinearDimension
  - MonotonicDimension
  - LabeledDimension
- How to add instances of DependentVariable class
  - Adding a scalar dependent variables
  - Adding a multi-component dependent variables
- How to save datasets
- A fun 🤪 example